@@ -5,9 +5,17 @@ Offsets
 
 from .offsets import Offsets
 from .astrometry import AstrometryOffsets
+from .brighteststar import BrightestStarOffsets
 from .nstar import NStarOffsets
 from .projected import ProjectedOffsets
 from .fitsheader import FitsHeaderOffsets
 
 
-__all__ = ["Offsets", "AstrometryOffsets", "NStarOffsets", "ProjectedOffsets", "FitsHeaderOffsets"]
+__all__ = [
+    "Offsets",
+    "AstrometryOffsets",
+    "NStarOffsets",
+    "ProjectedOffsets",
+    "FitsHeaderOffsets",
+    "BrightestStarOffsets",
+]
