@@ -6,7 +6,7 @@ from .interface import Interface
 
 class IOffsetsRaDec(Interface, metaclass=ABCMeta):
     """The module supports RA/Dec offsets, usually combined with :class:`~pyobs.interfaces.ITelescope` and
-    :class:`~pyobs.interfaces.IRaDec`."""
+    :class:`~pyobs.interfaces.IPointingRaDec`."""
 
     __module__ = "pyobs.interfaces"
 
@@ -19,7 +19,7 @@ class IOffsetsRaDec(Interface, metaclass=ABCMeta):
             ddec: Dec offset in degrees.
 
         Raises:
-            ValueError: If offset could not be set.
+            MoveError: If telescope cannot be moved.
         """
         ...
 
